==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/store2storetransfer_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.store2storetransfer_001;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.store2storetransfer_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.store2storetransfer_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Store2StoreTransfer }
     * 
     * @return
     *     the new instance of {@link Store2StoreTransfer }
     */
    public Store2StoreTransfer createStore2StoreTransfer() {
        return new Store2StoreTransfer();
    }

    /**
     * Create an instance of {@link Store2StoreTransfer.PartLines }
     * 
     * @return
     *     the new instance of {@link Store2StoreTransfer.PartLines }
     */
    public Store2StoreTransfer.PartLines createStore2StoreTransferPartLines() {
        return new Store2StoreTransfer.PartLines();
    }

    /**
     * Create an instance of {@link PartLine }
     * 
     * @return
     *     the new instance of {@link PartLine }
     */
    public PartLine createPartLine() {
        return new PartLine();
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/store2storetransfer_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.store2storetransfer_001;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.store2storetransfer_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.store2storetransfer_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Store2StoreTransfer }
     * 
     */
    public Store2StoreTransfer createStore2StoreTransfer() {
        return new Store2StoreTransfer();
    }

    /**
     * Create an instance of {@link Store2StoreTransfer.PartLines }
     * 
     */
    public Store2StoreTransfer.PartLines createStore2StoreTransferPartLines() {
        return new Store2StoreTransfer.PartLines();
    }

    /**
     * Create an instance of {@link PartLine }
     * 
     */
    public PartLine createPartLine() {
        return new PartLine();
    }

}
